@@ -22,7 +22,6 @@ class BaseAuth(object):
     ID_KEY = None
 
     def __init__(self, strategy=None, redirect_uri=None, *args, **kwargs):
-        self.titled_name = self.name.upper().replace('-', '_')
         self.strategy = strategy
         self.redirect_uri = redirect_uri
         self.data = {}
@@ -92,7 +91,7 @@ class BaseAuth(object):
             out.update(result)
         user = out['user']
         if user:
-            user.social_user = out['social_user']
+            user.social_user = out['social']
             user.is_new = out['is_new']
         return user
 
@@ -143,12 +142,6 @@ class BaseAuth(object):
         otherwise return false."""
         return True
 
-    def disconnect(self, user, association_id=None):
-        """Deletes current backend from user if associated.
-        Override if extra operations are needed.
-        """
-        self.strategy.disconnect(user=user, association_id=association_id)
-
     def request(self, url, method='GET', *args, **kwargs):
         kwargs.setdefault('timeout', self.setting('REQUESTS_TIMEOUT') or
                                      self.setting('URLOPEN_TIMEOUT'))
