@@ -12,18 +12,15 @@ to request.
 By default account id and token expiration time are stored in extra_data
 field, check OAuthBackend class for details on how to extend it.
 """
-import cgi
 import hmac
 import time
 import json
 import base64
 import hashlib
-from urllib import urlencode
-from urllib2 import HTTPError
 
+from social.utils import parse_qs
 from social.backends.oauth import BaseOAuth2
-from social.exceptions import AuthException, AuthCanceled, AuthFailed, \
-                              AuthTokenError, AuthUnknownError
+from social.exceptions import AuthException, AuthCanceled, AuthUnknownError
 
 
 class FacebookOAuth2(BaseOAuth2):
@@ -50,48 +47,30 @@ class FacebookOAuth2(BaseOAuth2):
         """Loads user data from service"""
         params = self.setting('PROFILE_EXTRA_PARAMS', {})
         params['access_token'] = access_token
-        url = 'https://graph.facebook.com/me?' + urlencode(params)
-        try:
-            return json.load(self.urlopen(url))
-        except ValueError:
-            return None
-        except HTTPError:
-            raise AuthTokenError(self)
+        return self.get_json('https://graph.facebook.com/me',
+                             params=params)
 
     def auth_complete(self, *args, **kwargs):
         """Completes loging process, must return user instance"""
-        if 'code' in self.data:
-            state = self.validate_state()
-            key, secret = self.get_key_and_secret()
-            url = self.ACCESS_TOKEN_URL + '?' + urlencode({
-                'client_id': key,
-                'redirect_uri': self.get_redirect_uri(state),
-                'client_secret': secret,
-                'code': self.data['code']
-            })
-            try:
-                response = cgi.parse_qs(self.urlopen(url).read())
-            except HTTPError:
-                raise AuthFailed(self, 'There was an error authenticating the'
-                                       'the app')
+        self.process_error(self.data)
+        state = self.validate_state()
+        key, secret = self.get_key_and_secret()
+        url = self.ACCESS_TOKEN_URL
+        response = self.get_querystring(url, params={
+            'client_id': key,
+            'redirect_uri': self.get_redirect_uri(state),
+            'client_secret': secret,
+            'code': self.data['code']
+        })
+        access_token = response['access_token']
+        return self.do_auth(access_token, response=response,
+                            *args, **kwargs)
 
-            access_token = response['access_token'][0]
-            expires = 'expires' in response and response['expires'][0] or None
-            return self.do_auth(access_token, expires=expires, *args, **kwargs)
-        else:
-            if self.data.get('error') == 'access_denied':
-                raise AuthCanceled(self)
-            else:
-                raise AuthException(self)
+    def process_refresh_token_response(self, response, *args, **kwargs):
+        return parse_qs(response.content)
 
-    @classmethod
-    def process_refresh_token_response(cls, response):
-        return dict((key, val[0])
-                        for key, val in cgi.parse_qs(response).iteritems())
-
-    @classmethod
-    def refresh_token_params(cls, token):
-        client_id, client_secret = cls.get_key_and_secret()
+    def refresh_token_params(self, token, *args, **kwargs):
+        client_id, client_secret = self.get_key_and_secret()
         return {
             'fb_exchange_token': token,
             'grant_type': 'fb_exchange_token',
@@ -99,7 +78,7 @@ class FacebookOAuth2(BaseOAuth2):
             'client_secret': client_secret
         }
 
-    def do_auth(self, access_token, expires=None, *args, **kwargs):
+    def do_auth(self, access_token, response, *args, **kwargs):
         data = self.user_data(access_token)
 
         if not isinstance(data, dict):
@@ -112,33 +91,11 @@ class FacebookOAuth2(BaseOAuth2):
                                          'users Facebook data')
 
         data['access_token'] = access_token
-        if expires:  # expires is None on offline access
-            data['expires'] = expires
-
+        if 'expires' in response:
+            data['expires'] = response['expires']
         kwargs.update({'backend': self, 'response': data})
         return self.strategy.authenticate(*args, **kwargs)
 
-    def load_signed_request(self, signed_request):
-        def base64_url_decode(data):
-            data = data.encode(u'ascii')
-            data += '=' * (4 - (len(data) % 4))
-            return base64.urlsafe_b64decode(data)
-
-        key, secret = self.get_key_and_secret()
-        try:
-            sig, payload = signed_request.split(u'.', 1)
-        except ValueError:
-            pass  # ignore if can't split on dot
-        else:
-            sig = base64_url_decode(sig)
-            data = json.loads(base64_url_decode(payload))
-            expected_sig = hmac.new(secret, msg=payload,
-                                    digestmod=hashlib.sha256).digest()
-            # allow the signed_request to function for upto 1 day
-            if sig == expected_sig and \
-               data['issued_at'] > (time.time() - 86400):
-                return data
-
 
 class FacebookAppOAuth2(FacebookOAuth2):
     """Facebook Application Authentication support"""
@@ -185,3 +142,24 @@ class FacebookAppOAuth2(FacebookOAuth2):
         }
         html = self.setting('LOCAL_HTML', 'facebook.html')
         return self.strategy.render_html(html, ctx)
+
+    def load_signed_request(self, signed_request):
+        def base64_url_decode(data):
+            data = data.encode('ascii')
+            data += '=' * (4 - (len(data) % 4))
+            return base64.urlsafe_b64decode(data)
+
+        key, secret = self.get_key_and_secret()
+        try:
+            sig, payload = signed_request.split('.', 1)
+        except ValueError:
+            pass  # ignore if can't split on dot
+        else:
+            sig = base64_url_decode(sig)
+            data = json.loads(base64_url_decode(payload))
+            expected_sig = hmac.new(secret, msg=payload,
+                                    digestmod=hashlib.sha256).digest()
+            # allow the signed_request to function for upto 1 day
+            if sig == expected_sig and \
+               data['issued_at'] > (time.time() - 86400):
+                return data
