@@ -1,16 +1,33 @@
 from flask import current_app, request, redirect, make_response, session, \
-                  render_template, render_template_string
+                  render_template, render_template_string, Response
 
-from social.strategies.base import BaseStrategy
+from social.strategies.base import BaseStrategy, BaseTemplateStrategy
+
+
+class FlaskTemplateStrategy(BaseTemplateStrategy):
+    def render_template(self, tpl, context):
+        return render_template(tpl, **context)
+
+    def render_string(self, html, context):
+        return render_template_string(html, **context)
 
 
 class FlaskStrategy(BaseStrategy):
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('tpl', FlaskTemplateStrategy)
+        super(FlaskStrategy, self).__init__(*args, **kwargs)
+
     def get_setting(self, name):
         return current_app.config[name]
 
-    def request_data(self):
-        data = request.form.copy()
-        data.update(request.args)
+    def request_data(self, merge=True):
+        if merge:
+            data = request.form.copy()
+            data.update(request.args)
+        elif request.method == 'POST':
+            data = request.form
+        else:
+            data = request.args
         return data
 
     def request_host(self):
@@ -24,21 +41,6 @@ class FlaskStrategy(BaseStrategy):
         response.headers['Content-Type'] = 'text/html;charset=UTF-8'
         return response
 
-    def render_html(self, tpl=None, html=None, context=None):
-        if not tpl and not html:
-            raise ValueError('Missing template or html parameters')
-        context = context or {}
-        if tpl:
-            return render_template(tpl, **context)
-        else:
-            return render_template_string(html, **context)
-
-    def authenticate(self, *args, **kwargs):
-        kwargs['strategy'] = self
-        kwargs['storage'] = self.storage
-        kwargs['backend'] = self.backend
-        return self.backend.authenticate(*args, **kwargs)
-
     def session_get(self, name, default=None):
         return session.get(name, default)
 
@@ -58,3 +60,6 @@ class FlaskStrategy(BaseStrategy):
         if request.host_url.endswith('/') and path.startswith('/'):
             path = path[1:]
         return request.host_url + (path or '')
+
+    def is_response(self, value):
+        return isinstance(value, Response)
